Package: psyphy
Type: Package
Title: Functions for Analyzing Psychophysical Data in R
Version: 0.3
Date: 2023-08-19
Author: Kenneth Knoblauch
Maintainer: Ken Knoblauch <ken.knoblauch@inserm.fr>
Depends: R (>= 3.0), stats, graphics
Suggests: MASS, nlme, lattice
LazyData: yes
Description: An assortment of functions that could be useful in analyzing data from psychophysical experiments. It includes functions for calculating d' from several different experimental designs, links for m-alternative forced-choice (mafc) data to be used with the binomial family in glm (and possibly other contexts) and self-Start functions for estimating gamma values for CRT screen calibrations.
License: GPL
NeedsCompilation: no
Packaged: 2023-08-19 13:51:23 UTC; ken
Repository: CRAN
Date/Publication: 2023-08-19 14:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 21:23:52 UTC; unix
